[java-opensaml COMMIT] in /trunk/opensaml-soap-api: pom.xml src/main/java/org/opensaml/soap/client/BasicSOAPMessageCo...

noreply at shibboleth.net noreply at shibboleth.net
Tue Jan 15 00:37:04 EST 2013


Author: scantor
Date: Tue Jan 15 00:37:04 2013
New Revision: 3150

URL: http://svn.shibboleth.net/view/java-opensaml?rev=3150&view=rev
Log:
OSJ-26: reworked SOAP client using v4 HttpClient API and new messaging APIs.

Added:
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClientContext.java   (with props)
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/http/package-info.java   (with props)
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/package-info.java   (with props)
Modified:
    trunk/opensaml-soap-api/pom.xml
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/BasicSOAPMessageContext.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClient.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClientException.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPFaultException.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/http/HttpClientBuilder.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/http/HttpSOAPClient.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/http/HttpSOAPRequestParameters.java
    trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/http/TLSProtocolSocketFactory.java

Modified: trunk/opensaml-soap-api/pom.xml
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-soap-api/pom.xml?rev=3150&r1=3149&r2=3150&view=diff
==============================================================================
--- trunk/opensaml-soap-api/pom.xml (original)
+++ trunk/opensaml-soap-api/pom.xml Tue Jan 15 00:37:04 2013
@@ -33,25 +33,17 @@
             <artifactId>opensaml-temp</artifactId>
             <version>${project.version}</version>
         </dependency>
-        <dependency>
-            <!-- TODO this needs to be replaced with the v4 client -->
-            <groupId>commons-httpclient</groupId>
-            <artifactId>commons-httpclient</artifactId>
-            <version>3.1</version>
-            <exclusions>
-                <exclusion>
-                    <groupId>commons-logging</groupId>
-                    <artifactId>commons-logging</artifactId>
-                </exclusion>
-            </exclusions>
-        </dependency>
 
         <!-- Provided Dependencies -->
 
         <!-- Runtime Dependencies -->
 
         <!-- Test Dependencies -->
-        
+
+        <dependency>
+            <groupId>org.apache.httpcomponents</groupId>
+            <artifactId>httpclient</artifactId>
+        </dependency>
     </dependencies>
     
 </project>

Modified: trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClient.java
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClient.java?rev=3150&r1=3149&r2=3150&view=diff
==============================================================================
--- trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClient.java (original)
+++ trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClient.java Tue Jan 15 00:37:04 2013
@@ -19,8 +19,10 @@
 
 import javax.annotation.concurrent.ThreadSafe;
 
+import org.opensaml.messaging.context.InOutOperationContext;
 import org.opensaml.security.SecurityException;
 import org.opensaml.soap.common.SOAPException;
+
 
 /**
  * An interface for a very basic SOAP client.
@@ -35,14 +37,14 @@
      * Sends a message and waits for a response.
      * 
      * @param endpoint the endpoint to which to send the message
      * @param messageContext the message context containing the outbound SOAP message
      * 
-     * @throws SOAPClientException thrown if there is a problem sending the message or receiving the response or if the
+     * @throws SOAPException thrown if there is a problem sending the message or receiving the response or if the
      *             response is a SOAP fault
      * @throws SecurityException thrown if the response does not meet any security policy associated with the message
      *             context
      */
-    public void send(String endpoint, SOAPMessageContext messageContext) throws SOAPException, SecurityException;
+    public void send(String endpoint, InOutOperationContext context) throws SOAPException, SecurityException;
 
     /** Marker interface for binding/transport request parameters. */
     public interface SOAPRequestParameters {};

Modified: trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClientException.java
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClientException.java?rev=3150&r1=3149&r2=3150&view=diff
==============================================================================
--- trunk/opensaml-soap-api/src/main/java/org/opensaml/soap/client/SOAPClientException.java (original)
@@ -35,14 +37,14 @@
      * 
      * @param endpoint the endpoint to which to send the message
-     * @param messageContext the message context containing the outbound SOAP message
+     * @param context the operation context containing the outbound SOAP message
      * 

[... 518 lines stripped ...]


More information about the commits mailing list